abacusai.api_class.enums — AbacusAI documentation

# `abacusai.api_class.enums`

## Module Contents

### Classes

`ApiEnum` | Generic enumeration.
`ProblemType` | Generic enumeration.
`RegressionObjective` | Generic enumeration.
`RegressionTreeHPOMode` | Generic enumeration.
`PartialDependenceAnalysis` | Generic enumeration.
`RegressionAugmentationStrategy` | Generic enumeration.
`RegressionTargetTransform` | Generic enumeration.
`RegressionTypeOfSplit` | Generic enumeration.
`RegressionTimeSplitMethod` | Generic enumeration.
`RegressionLossFunction` | Generic enumeration.
`ExplainerType` | Generic enumeration.
`SamplingMethodType` | Generic enumeration.
`MergeMode` | Generic enumeration.
`FillLogic` | Generic enumeration.
`BatchSize` | Generic enumeration.
`HolidayCalendars` | Generic enumeration.
`FileFormat` | Generic enumeration.
`ExperimentationMode` | Generic enumeration.
`PersonalizationTrainingMode` | Generic enumeration.
`PersonalizationObjective` | Generic enumeration.
`ForecastingObjective` | Generic enumeration.
`ForecastingFrequency` | Generic enumeration.
`ForecastingDataSplitType` | Generic enumeration.
`ForecastingLossFunction` | Generic enumeration.
`ForecastingLocalScaling` | Generic enumeration.
`ForecastingFillMethod` | Generic enumeration.
`ForecastingQuanitlesExtensionMethod` | Generic enumeration.
`TimeseriesAnomalyDataSplitType` | Generic enumeration.
`TimeseriesAnomalyTypeOfAnomaly` | Generic enumeration.
`NERObjective` | Generic enumeration.
`NERModelType` | Generic enumeration.
`NLPDocumentFormat` | Generic enumeration.
`SentimentType` | Generic enumeration.
`ClusteringImputationMethod` | Generic enumeration.
`ConnectorType` | Generic enumeration.
`ApplicationConnectorType` | Generic enumeration.
`PythonFunctionArgumentType` | Generic enumeration.
`PythonFunctionOutputArgumentType` | Generic enumeration.
`VectorStoreTextEncoder` | Generic enumeration.
`LLMName` | Generic enumeration.
`MonitorAlertType` | Generic enumeration.
`FeatureDriftType` | Generic enumeration.
`DataIntegrityViolationType` | Generic enumeration.
`BiasType` | Generic enumeration.
`AlertActionType` | Generic enumeration.
`PythonFunctionType` | Generic enumeration.
`EvalArtifactType` | Generic enumeration.
`FieldDescriptorType` | Generic enumeration.
`OcrMode` | Generic enumeration.
`DataType` | Generic enumeration.

class abacusai.api_class.enums.ApiEnum

  Bases: `enum.Enum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  __eq__(other)

    Return self==value.

  __hash__()

    Return hash(self).

class abacusai.api_class.enums.ProblemType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  AI_AGENT = 'ai_agent'
  ANOMALY_OUTLIERS = 'anomaly'
  EVENT_ANOMALY = 'event_anomaly'
  CLUSTERING = 'clustering'
  CLUSTERING_TIMESERIES = 'clustering_timeseries'
  CUMULATIVE_FORECASTING = 'cumulative_forecasting'
  NAMED_ENTITY_EXTRACTION = 'nlp_ner'
  NATURAL_LANGUAGE_SEARCH = 'nlp_search'
  CHAT_LLM = 'chat_llm'
  SENTENCE_BOUNDARY_DETECTION = 'nlp_sentence_boundary_detection'
  SENTIMENT_DETECTION = 'nlp_sentiment'
  DOCUMENT_CLASSIFICATION = 'nlp_classification'
  DOCUMENT_SUMMARIZATION = 'nlp_summarization'
  DOCUMENT_VISUALIZATION = 'nlp_document_visualization'
  PERSONALIZATION = 'personalization'
  PREDICTIVE_MODELING = 'regression'
  FINETUNED_LLM = 'finetuned_llm'
  FORECASTING = 'forecasting'
  CUSTOM_TRAINED_MODEL = 'plug_and_play'
  CUSTOM_ALGORITHM = 'trainable_plug_and_play'
  FEATURE_STORE = 'feature_store'
  IMAGE_CLASSIFICATION = 'vision_classification'
  OBJECT_DETECTION = 'vision_object_detection'
  IMAGE_VALUE_PREDICTION = 'vision_regression'
  MODEL_MONITORING = 'model_monitoring'
  LANGUAGE_DETECTION = 'language_detection'
  OPTIMIZATION = 'optimization'
  PRETRAINED_MODELS = 'pretrained'
  THEME_ANALYSIS = 'theme_analysis'
  TS_ANOMALY = 'ts_anomaly'

class abacusai.api_class.enums.RegressionObjective

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  AUC = 'auc'
  ACCURACY = 'acc'
  LOG_LOSS = 'log_loss'
  PRECISION = 'precision'
  RECALL = 'recall'
  F1_SCORE = 'fscore'
  MAE = 'mae'
  MAPE = 'mape'
  WAPE = 'wape'
  RMSE = 'rmse'
  R_SQUARED_COEFFICIENT_OF_DETERMINATION = 'r^2'

class abacusai.api_class.enums.RegressionTreeHPOMode

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  RAPID = 'rapid'
  THOROUGH = 'thorough'

class abacusai.api_class.enums.PartialDependenceAnalysis

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  RAPID = 'rapid'
  THOROUGH = 'thorough'

class abacusai.api_class.enums.RegressionAugmentationStrategy

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  SMOTE = 'smote'
  RESAMPLE = 'resample'

class abacusai.api_class.enums.RegressionTargetTransform

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  LOG = 'log'
  QUANTILE = 'quantile'
  YEO_JOHNSON = 'yeo-johnson'
  BOX_COX = 'box-cox'

class abacusai.api_class.enums.RegressionTypeOfSplit

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  RANDOM = 'Random Sampling'
  TIMESTAMP_BASED = 'Timestamp Based'
  ROW_INDICATOR_BASED = 'Row Indicator Based'

class abacusai.api_class.enums.RegressionTimeSplitMethod

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  TEST_SPLIT_PERCENTAGE_BASED = 'Test Split Percentage Based'
  TEST_START_TIMESTAMP_BASED = 'Test Start Timestamp Based'

class abacusai.api_class.enums.RegressionLossFunction

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  HUBER = 'Huber'
  MSE = 'Mean Squared Error'
  MAE = 'Mean Absolute Error'
  MAPE = 'Mean Absolute Percentage Error'
  MSLE = 'Mean Squared Logarithmic Error'
  TWEEDIE = 'Tweedie'
  CROSS_ENTROPY = 'Cross Entropy'
  FOCAL_CROSS_ENTROPY = 'Focal Cross Entropy'
  AUTOMATIC = 'Automatic'
  CUSTOM = 'Custom'

class abacusai.api_class.enums.ExplainerType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  KERNEL_EXPLAINER = 'KERNEL_EXPLAINER'
  LIME_EXPLAINER = 'LIME_EXPLAINER'
  TREE_EXPLAINER = 'TREE_EXPLAINER'
  EBM_EXPLAINER = 'EBM_EXPLAINER'

class abacusai.api_class.enums.SamplingMethodType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  N_SAMPLING = 'N_SAMPLING'
  PERCENT_SAMPLING = 'PERCENT_SAMPLING'

class abacusai.api_class.enums.MergeMode

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  LAST_N = 'LAST_N'
  TIME_WINDOW = 'TIME_WINDOW'

class abacusai.api_class.enums.FillLogic

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  AVERAGE = 'average'
  MAX = 'max'
  MEDIAN = 'median'
  MIN = 'min'
  CUSTOM = 'custom'
  BACKFILL = 'bfill'
  FORWARDFILL = 'ffill'
  LINEAR = 'linear'
  NEAREST = 'nearest'

class abacusai.api_class.enums.BatchSize

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  BATCH_8 = 8
  BATCH_16 = 16
  BATCH_32 = 32
  BATCH_64 = 64
  BATCH_128 = 128
  BATCH_256 = 256
  BATCH_384 = 384
  BATCH_512 = 512
  BATCH_740 = 740
  BATCH_1024 = 1024

class abacusai.api_class.enums.HolidayCalendars

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  AU = 'AU'
  UK = 'UK'
  US = 'US'

class abacusai.api_class.enums.FileFormat

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  AVRO = 'AVRO'
  PARQUET = 'PARQUET'
  TFRECORD = 'TFRECORD'
  TSV = 'TSV'
  CSV = 'CSV'
  ORC = 'ORC'
  JSON = 'JSON'
  ODS = 'ODS'
  XLS = 'XLS'
  GZ = 'GZ'
  ZIP = 'ZIP'
  TAR = 'TAR'
  DOCX = 'DOCX'
  PDF = 'PDF'
  RAR = 'RAR'
  JPEG = 'JPG'
  PNG = 'PNG'
  TIF = 'TIFF'
  NUMBERS = 'NUMBERS'
  PPTX = 'PPTX'
  PPT = 'PPT'
  HTML = 'HTML'

class abacusai.api_class.enums.ExperimentationMode

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  RAPID = 'rapid'
  THOROUGH = 'thorough'

class abacusai.api_class.enums.PersonalizationTrainingMode

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  EXPERIMENTAL = 'EXP'
  PRODUCTION = 'PROD'

class abacusai.api_class.enums.PersonalizationObjective

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  NDCG = 'ndcg'
  NDCG_5 = 'ndcg@5'
  NDCG_10 = 'ndcg@10'
  MAP = 'map'
  MAP_5 = 'map@5'
  MAP_10 = 'map@10'
  MRR = 'mrr'
  PERSONALIZATION = 'personalization@10'
  COVERAGE = 'coverage'

class abacusai.api_class.enums.ForecastingObjective

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  ACCURACY = 'w_c_accuracy'
  WAPE = 'wape'
  MAPE = 'mape'
  CMAPE = 'cmape'
  RMSE = 'rmse'
  CV = 'coefficient_of_variation'
  BIAS = 'bias'
  SRMSE = 'srmse'

class abacusai.api_class.enums.ForecastingFrequency

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  HOURLY = '1H'
  DAILY = '1D'
  WEEKLY_SUNDAY_START = '1W'
  WEEKLY_MONDAY_START = 'W-MON'
  WEEKLY_SATURDAY_START = 'W-SAT'
  MONTH_START = 'MS'
  MONTH_END = '1M'
  QUARTER_START = 'QS'
  QUARTER_END = '1Q'
  YEARLY = '1Y'

class abacusai.api_class.enums.ForecastingDataSplitType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  AUTO = 'Automatic Time Based'
  TIMESTAMP = 'Timestamp Based'
  ITEM = 'Item Based'
  PREDICTION_LENGTH = 'Force Prediction Length'

class abacusai.api_class.enums.ForecastingLossFunction

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  CUSTOM = 'Custom'
  MEAN_ABSOLUTE_ERROR = 'mae'
  NORMALIZED_MEAN_ABSOLUTE_ERROR = 'nmae'
  PEAKS_MEAN_ABSOLUTE_ERROR = 'peaks_mae'
  MEAN_ABSOLUTE_PERCENTAGE_ERROR = 'stable_mape'
  POINTWISE_ACCURACY = 'accuracy'
  ROOT_MEAN_SQUARE_ERROR = 'rmse'
  NORMALIZED_ROOT_MEAN_SQUARE_ERROR = 'nrmse'
  ASYMMETRIC_MEAN_ABSOLUTE_PERCENTAGE_ERROR = 'asymmetric_mape'
  STABLE_STANDARDIZED_MEAN_ABSOLUTE_PERCENTAGE_ERROR = 'stable_standardized_mape_with_cmape'
  GAUSSIAN = 'mle_gaussian_local'
  GAUSSIAN_FULL_COVARIANCE = 'mle_gaussfullcov'
  GUASSIAN_EXPONENTIAL = 'mle_gaussexp'
  MIX_GAUSSIANS = 'mle_gaussmix'
  WEIBULL = 'mle_weibull'
  NEGATIVE_BINOMIAL = 'mle_negbinom'
  LOG_ROOT_MEAN_SQUARE_ERROR = 'log_rmse'

class abacusai.api_class.enums.ForecastingLocalScaling

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  ZSCORE = 'zscore'
  SLIDING_ZSCORE = 'sliding_zscore'
  LAST_POINT = 'lastpoint'
  MIN_MAX = 'minmax'
  MIN_STD = 'minstd'
  ROBUST = 'robust'
  ITEM = 'item'

class abacusai.api_class.enums.ForecastingFillMethod

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  BACK = 'BACK'
  MIDDLE = 'MIDDLE'
  FUTURE = 'FUTURE'

class abacusai.api_class.enums.ForecastingQuanitlesExtensionMethod

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  DIRECT = 'direct'
  QUADRATIC = 'quadratic'
  ANCESTRAL_SIMULATION = 'simulation'

class abacusai.api_class.enums.TimeseriesAnomalyDataSplitType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  AUTO = 'Automatic Time Based'
  TIMESTAMP = 'Fixed Timestamp Based'

class abacusai.api_class.enums.TimeseriesAnomalyTypeOfAnomaly

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  HIGH_PEAK = 'high_peak'
  LOW_PEAK = 'low_peak'

class abacusai.api_class.enums.NERObjective

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  LOG_LOSS = 'log_loss'
  AUC = 'auc'
  PRECISION = 'precision'
  RECALL = 'recall'
  ANNOTATIONS_PRECISION = 'annotations_precision'
  ANNOTATIONS_RECALL = 'annotations_recall'

class abacusai.api_class.enums.NERModelType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  PRETRAINED_BERT = 'pretrained_bert'
  PRETRAINED_ROBERTA_27 = 'pretrained_roberta_27'
  PRETRAINED_ROBERTA_43 = 'pretrained_roberta_43'
  PRETRAINED_MULTILINGUAL = 'pretrained_multilingual'
  LEARNED = 'learned'

class abacusai.api_class.enums.NLPDocumentFormat

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  AUTO = 'auto'
  TEXT = 'text'
  DOC = 'doc'
  TOKENS = 'tokens'

class abacusai.api_class.enums.SentimentType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  VALENCE = 'valence'
  EMOTION = 'emotion'

class abacusai.api_class.enums.ClusteringImputationMethod

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  AUTOMATIC = 'Automatic'
  ZEROS = 'Zeros'
  INTERPOLATE = 'Interpolate'

class abacusai.api_class.enums.ConnectorType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  FILE = 'FILE'
  DATABASE = 'DATABASE'
  STREAMING = 'STREAMING'
  APPLICATION = 'APPLICATION'

class abacusai.api_class.enums.ApplicationConnectorType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  GOOGLEANALYTICS = 'GOOGLEANALYTICS'
  GOOGLEDRIVE = 'GOOGLEDRIVE'
  GIT = 'GIT'
  CONFLUENCE = 'CONFLUENCE'
  JIRA = 'JIRA'
  ONEDRIVE = 'ONEDRIVE'
  ZENDESK = 'ZENDESK'
  SLACK = 'SLACK'
  SHAREPOINT = 'SHAREPOINT'
  TEAMS = 'TEAMS'
  ABACUSUSAGEMETRICS = 'ABACUSUSAGEMETRICS'
  MICROSOFTAUTH = 'MICROSOFTAUTH'

class abacusai.api_class.enums.PythonFunctionArgumentType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  FEATURE_GROUP = 'FEATURE_GROUP'
  INTEGER = 'INTEGER'
  STRING = 'STRING'
  BOOLEAN = 'BOOLEAN'
  FLOAT = 'FLOAT'
  JSON = 'JSON'
  LIST = 'LIST'
  DATASET_ID = 'DATASET_ID'
  MODEL_ID = 'MODEL_ID'
  FEATURE_GROUP_ID = 'FEATURE_GROUP_ID'
  MONITOR_ID = 'MONITOR_ID'
  BATCH_PREDICTION_ID = 'BATCH_PREDICTION_ID'
  DEPLOYMENT_ID = 'DEPLOYMENT_ID'

class abacusai.api_class.enums.PythonFunctionOutputArgumentType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  NTEGER = 'INTEGER'
  STRING = 'STRING'
  BOOLEAN = 'BOOLEAN'
  FLOAT = 'FLOAT'
  JSON = 'JSON'
  LIST = 'LIST'
  DATASET_ID = 'DATASET_ID'
  MODEL_ID = 'MODEL_ID'
  FEATURE_GROUP_ID = 'FEATURE_GROUP_ID'
  MONITOR_ID = 'MONITOR_ID'
  BATCH_PREDICTION_ID = 'BATCH_PREDICTION_ID'
  DEPLOYMENT_ID = 'DEPLOYMENT_ID'
  ANY = 'ANY'

class abacusai.api_class.enums.VectorStoreTextEncoder

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  E5 = 'E5'
  OPENAI = 'OPENAI'
  SENTENCE_BERT = 'SENTENCE_BERT'
  E5_SMALL = 'E5_SMALL'

class abacusai.api_class.enums.LLMName

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  OPENAI_GPT4 = 'OPENAI_GPT4'
  OPENAI_GPT4_32K = 'OPENAI_GPT4_32K'
  OPENAI_GPT4_128K = 'OPENAI_GPT4_128K'
  OPENAI_GPT3_5 = 'OPENAI_GPT3_5'
  OPENAI_GPT3_5_TEXT = 'OPENAI_GPT3_5_TEXT'
  CLAUDE_V2_1 = 'CLAUDE_V2_1'
  ABACUS_GIRAFFE = 'ABACUS_GIRAFFE'
  ABACUS_GIRAFFE_LARGE = 'ABACUS_GIRAFFE_LARGE'
  ABACUS_LLAMA2_QA = 'ABACUS_LLAMA2_QA'
  LLAMA2_CHAT = 'LLAMA2_CHAT'
  PALM = 'PALM'
  PALM_TEXT = 'PALM_TEXT'
  GEMINI_PRO = 'GEMINI_PRO'
  MIXTRAL_CHAT = 'MIXTRAL_CHAT'
  MISTRAL_MEDIUM = 'MISTRAL_MEDIUM'

class abacusai.api_class.enums.MonitorAlertType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  ACCURACY_BELOW_THRESHOLD = 'AccuracyBelowThreshold'
  FEATURE_DRIFT = 'FeatureDrift'
  DATA_INTEGRITY_VIOLATIONS = 'DataIntegrityViolations'
  BIAS_VIOLATIONS = 'BiasViolations'
  HISTORY_LENGTH_DRIFT = 'HistoryLengthDrift'
  TARGET_DRIFT = 'TargetDrift'
  PREDICTION_COUNT = 'PredictionCount'

class abacusai.api_class.enums.FeatureDriftType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  KL = 'kl'
  KS = 'ks'
  WS = 'ws'
  JS = 'js'
  PSI = 'psi'
  CHI_SQUARE = 'chi_square'
  CSI = 'csi'

class abacusai.api_class.enums.DataIntegrityViolationType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  NULL_VIOLATIONS = 'null_violations'
  TYPE_MISMATCH_VIOLATIONS = 'type_mismatch_violations'
  RANGE_VIOLATIONS = 'range_violations'
  CATEGORICAL_RANGE_VIOLATION = 'categorical_range_violations'
  TOTAL_VIOLATIONS = 'total_violations'

class abacusai.api_class.enums.BiasType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  DEMOGRAPHIC_PARITY = 'demographic_parity'
  EQUAL_OPPORTUNITY = 'equal_opportunity'
  GROUP_BENEFIT_EQUALITY = 'group_benefit'
  TOTAL = 'total'

class abacusai.api_class.enums.AlertActionType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  EMAIL = 'Email'

class abacusai.api_class.enums.PythonFunctionType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  FEATURE_GROUP = 'FEATURE_GROUP'
  PLOTLY_FIG = 'PLOTLY_FIG'
  STEP_FUNCTION = 'STEP_FUNCTION'

class abacusai.api_class.enums.EvalArtifactType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  FORECASTING_ACCURACY = 'bar_chart'
  FORECASTING_VOLUME = 'bar_chart_volume'
  FORECASTING_HISTORY_LENGTH_ACCURACY = 'bar_chart_accuracy_by_history'

class abacusai.api_class.enums.FieldDescriptorType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  STRING = 'STRING'
  INTEGER = 'INTEGER'
  FLOAT = 'FLOAT'
  BOOLEAN = 'BOOLEAN'
  DATETIME = 'DATETIME'
  DATE = 'DATE'

class abacusai.api_class.enums.OcrMode

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  DEFAULT = 'DEFAULT'
  LAYOUT = 'LAYOUT'
  SCANNED = 'SCANNED'
  COMPREHENSIVE = 'COMPREHENSIVE'
  COMPREHENSIVE_V2 = 'COMPREHENSIVE_V2'
  COMPREHENSIVE_TABLE_MD = 'COMPREHENSIVE_TABLE_MD'

class abacusai.api_class.enums.DataType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  INTEGER = 'integer'
  FLOAT = 'float'
  STRING = 'string'
  DATE = 'date'
  DATETIME = 'datetime'
  BOOLEAN = 'boolean'
  LIST = 'list'
  STRUCT = 'struct'
  NULL = 'null'
  classmethod from_str(value)